# clustaar.schemas
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

This library defines JSON schemas for Step Actions used in the 
[Clustaar Bot Builder](https://app.clustaar.com/).

They are useful when you want to use our 
[API](https://developers.clustaar.com/docs/talk-to-a-bot-with-the-api), 
or build a [Webhook](https://developers.clustaar.com/docs/webhook-1) for your Bot.
